==> openshift-model-miscellaneous-5.12.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ConfigListBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConfigListBuilder extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigListFluentImpl<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigList,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigListBuilder>{
  public ConfigListBuilder() {
    this(false);
  }
  public ConfigListBuilder(java.lang.Boolean validationEnabled) {
    this(new ConfigList(), validationEnabled);
  }
  public ConfigListBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigListFluent<?> fluent) {
    this(fluent, false);
  }
  public ConfigListBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConfigList(), validationEnabled);
  }
  public ConfigListBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigListFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigList instance) {
    this(fluent, instance, false);
  }
  public ConfigListBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigListFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConfigListBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigList instance) {
    this(instance,false);
  }
  public ConfigListBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigList build() {
    ConfigList buildable = new ConfigList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConfigListBuilder that = (ConfigListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.6.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ConfigListBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConfigListBuilder extends ConfigListFluentImpl<ConfigListBuilder> implements VisitableBuilder<ConfigList,ConfigListBuilder>{
  public ConfigListBuilder() {
    this(false);
  }
  public ConfigListBuilder(Boolean validationEnabled) {
    this(new ConfigList(), validationEnabled);
  }
  public ConfigListBuilder(ConfigListFluent<?> fluent) {
    this(fluent, false);
  }
  public ConfigListBuilder(ConfigListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConfigList(), validationEnabled);
  }
  public ConfigListBuilder(ConfigListFluent<?> fluent,ConfigList instance) {
    this(fluent, instance, false);
  }
  public ConfigListBuilder(ConfigListFluent<?> fluent,ConfigList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConfigListBuilder(ConfigList instance) {
    this(instance,false);
  }
  public ConfigListBuilder(ConfigList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ConfigListFluent<?> fluent;
  Boolean validationEnabled;
  public ConfigList build() {
    ConfigList buildable = new ConfigList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
